import os
from PyQt5 import uic
from PyQt5.QtWidgets import QDialog

from qgis.core import QgsFeatureRequest

from ..paggf_utils import PAGGFUtils
from ..paggf_layers import LoadedLayers


SELECT_W, _ = uic.loadUiType(os.path.join(
    os.path.dirname(__file__), 'select_municipality.ui'))

class SelectMunicipalityDlg(QDialog, SELECT_W):
    def __init__(self, parent=None):
        QDialog.__init__(self, parent)
        self.setupUi(self)

        self.layers = LoadedLayers()
        self.utils = PAGGFUtils(self.layers)

        self.provinces_idx = {}
        self.municipalities_idx = {}

        # populate combos
        province_layer = self.layers.get("ref", "provinces")
        if province_layer:
            idx=0
            req = QgsFeatureRequest().setSubsetOfAttributes([province_layer.fields().indexFromName(x) for x in ["id","name"]]).addOrderBy("id")
            for f in province_layer.getFeatures(req):
                self.province_field.addItem(
                    "{} - {}".format(f['id'], f['name']), f['id'])
                self.provinces_idx[f['id']]=idx
                idx+=1
        self.province_field.activated[int].connect(
            self.when_province_selection_changed)

        # select the current municipality, if any:
        current_municipality = self.utils.get_current_municipality()
        if current_municipality:
            id = current_municipality['id']
            self.province_field.setCurrentIndex(self.provinces_idx[id[0:2]])
            self.when_province_selection_changed(self.provinces_idx[id[0:2]])
            self.municipality_field.setCurrentIndex(self.municipalities_idx[id[0:4]])
        else:
            self.province_field.setCurrentIndex(0)
            self.municipality_field.setCurrentIndex(0)
            self.when_province_selection_changed(0)

    def when_province_selection_changed(self, index):
        self.municipalities_idx = {}
        mun_layer = self.layers.get("ref", "municipalities")
        self.municipality_field.clear()
        if mun_layer:
            idx = 0
            req = QgsFeatureRequest().setSubsetOfAttributes([mun_layer.fields().indexFromName(x) for x in ["id", "name"]])
            for f in mun_layer.getFeatures(req):
                if f['id'].startswith(self.province_field.currentData()):
                    self.municipality_field.addItem(
                        "{} - {}".format(f['id'], f['name']), f['id'])
                    self.municipalities_idx[f['id']] = idx
                    idx += 1

    def province_id(self):
        return self.province_field.currentData()
    
    def municipality_id(self):
        return self.municipality_field.currentData()
